@@ -13,25 +13,25 @@ __all__ = [
 ]
 
 
-def as_int(value) -> int:
+def as_int(value, default: int = 0) -> int:
     if not value:
-        return 0
+        return default
     return int(value)
 
 
-def as_float(value) -> float:
+def as_float(value, default: float = 0.0) -> float:
     if not value:
-        return 0.0
+        return default
     return float(str(value).replace(",", "."))
 
 
-def as_str(value) -> str:
+def as_str(value, default: str = "") -> str:
     if not value:
-        return ""
+        return default
     return str(value)
 
 
-def as_bool(value) -> bool:
+def as_bool(value, default: bool = False) -> bool:
     if value is not True and value is not False:
-        return False
+        return default
     return bool(value)
